import locale


def locale_currency(currency, amount):
    locale.setlocale(locale.LC_ALL, 'zh_CN.UTF-8' if currency == 'CNY' else '')
    locale._override_localeconv = {'n_sign_posn': 1}
    return locale.currency(amount, grouping=True)



from rest_framework.pagination import PageNumberPagination
from rest_framework.settings import api_settings


class StandardResultsSetPagination(PageNumberPagination):
    page_size = api_settings.PAGE_SIZE if api_settings.PAGE_SIZE else 20
    page_size_query_param = 'page_size'
    max_page_size = 1000



import datetime

from django.apps.registry import apps
from django.conf import settings
from django.conf.urls.static import static
from django.contrib import admin
from django.contrib.auth.decorators import login_required
from django.urls import include, path, re_path
from django.utils.translation import gettext, gettext_lazy as _
from django.views.decorators.cache import cache_page
from django.views.generic.base import RedirectView
from django.views.i18n import JavaScriptCatalog
from rest_framework import permissions
from rest_framework.documentation import include_docs_urls
from rest_framework.schemas import get_schema_view
from rest_framework_simplejwt.views import token_obtain_sliding, token_refresh_sliding

from .django.generics import WebView
from .django.utils.translation import dj_gettext
from .rest_framework.views import DownloadUrlView, UploadParamsView

API_TITLE = f'{gettext("app_name")} API'
API_VERSION = settings.REST_FRAMEWORK.get('DEFAULT_VERSION', '')
API_DESCRIPTION = 'API documentation'

# Django
urlpatterns = [
    path('admin/', admin.site.urls),
    path('i18n/', include('django.conf.urls.i18n')),
    path('jsi18n/',
         cache_page(86400,
                    key_prefix=f'js18n-{datetime.datetime.now().strftime("%Y%m%d")}')(JavaScriptCatalog.as_view()),
         name='javascript-catalog')
]
# Vendor :: Django REST framework
urlpatterns += [
    path('api-auth/', include('rest_framework.urls')),
    path('docs/',
         include_docs_urls(title=API_TITLE, description=API_DESCRIPTION, permission_classes=[permissions.IsAdminUser])),
    path('openapi',
         get_schema_view(title=f'{API_TITLE} {API_VERSION}', description=API_DESCRIPTION),
         name='openapi-schema')
]
# Vendor :: Others
urlpatterns += [
    path('api/token/', token_obtain_sliding, name='token_obtain'),
    path('api/token/refresh/', token_refresh_sliding, name='token_refresh'),
    # path('rest-auth/', include('rest_auth.urls')),
    # path('search/', include('haystack.urls'))
]
# Railgun S
urlpatterns += [
    re_path(r'^download-url/(?P<cloud>(aliyun|aws))/$', DownloadUrlView.as_view(), name='download-url'),
    re_path(r'^upload-params/(?P<cloud>(aliyun|aws))/$', UploadParamsView.as_view(), name='upload-params'),
    path('favicon.ico', RedirectView.as_view(url=f'{settings.STATIC_URL}favicon.ico', permanent=True)),
    # update
    path('radio-update/',
         login_required(
             WebView.as_view(name='radio-update',
                             title=dj_gettext('Update'),
                             endpoint=None,
                             template_name='railguns/ui/radio_update.html')),
         name='radio-update'),
    path('text-field-update/',
         login_required(
             WebView.as_view(name='text_field_update',
                             title=dj_gettext('Update'),
                             endpoint=None,
                             template_name='railguns/ui/text_field_update.html')),
         name='text-field-update')
]

urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)

if apps.is_installed('rosetta'):
    urlpatterns += [path('rosetta/', include('rosetta.urls'))]

admin.site.site_header = _('app_name')
admin.site.site_title = _('app_name')



from django.utils.text import format_lazy
from django.utils.translation import gettext_lazy as _


def dj_gettext(message):
    """获取Django原生翻译"""
    return _(message)


def format_gettext_lazy(message1, message2):
    return format_lazy('{} {}', _(message1), _(message2))


def get_untranslated_text(text):
    # SO https://stackoverflow.com/questions/5143822/access-untranslated-content-of-djangos-ugettext-lazy
    # with translation.override('en'):
    #     return force_text(text)
    untranslated_text = text
    try:
        untranslated_text = text._proxy____args[0]  # 虽然不建议使用, 但是不用的话得到的是英语翻译的(首字母会大写)
    except Exception as e:
        print(f'Exception: {text} {e}')
    return untranslated_text



from django.db.models import Field

from .widgets import CloudFileWidget


class CloudFileField(Field):

    def __init__(self, *args, **kwargs):
        dest = kwargs.pop('dest', None)
        self.widget = CloudFileWidget(dest=dest)
        super().__init__(*args, **kwargs)

    def get_internal_type(self):
        return 'TextField'

    def formfield(self, *args, **kwargs):
        kwargs['widget'] = self.widget
        return super().formfield(*args, **kwargs)



import os

from setuptools import find_packages, setup


def read(fname):
    with open(os.path.join(os.path.dirname(__file__), fname)) as f:
        return f.read()


setup(
    name='RailgunS',
    version='0.34',
    url='https://github.com/nyssance/railguns',
    author='NY',
    author_email='nyssance@icloud.com',
    description='Only My Railgun',
    long_description=read('README.md'),
    long_description_content_type='text/markdown',
    license='MIT',
    packages=find_packages(exclude=['tests']),
    include_package_data=True,
    install_requires=[
        'django[argon2]==3.0.8',
        'djangorestframework==3.11.0',
        'djangorestframework_simplejwt==4.4.0',
        'gunicorn==20.0.4',
        'uvicorn==0.11.6',
        #
        'django-ckeditor==5.9.0',
        'django-filter==2.3.0',
        'django-htmlmin==0.11.0',
        'django-redis-cache==2.1.1',
        'hiredis==1.0.1',
        'mysqlclient==2.0.1'
    ],
    extras_require={
        'dev': [],
        'prod': []
    },
    python_requires='>=3.8',
    zip_safe=False,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 3.0',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3 :: Only',
        'Topic :: Internet :: WWW/HTTP'
    ],
    project_urls={'Source': 'https://github.com/nyssance/railguns'})
